expr_batch_arena_bytes

Function expr_batch_arena_bytes 

#[unsafe(no_mangle)]
pub extern "C" fn expr_batch_arena_bytes( batch: *const ExprBatch, ) -> usize
Get the high water mark of arena memory usage for a batch

Parameters

  • batch: The batch

Returns

Number of bytes currently allocated in the batch’s arena. This represents the maximum memory usage of the arena.