expr_batch_new

Function expr_batch_new 

#[unsafe(no_mangle)]
pub extern "C" fn expr_batch_new(size_hint: usize) -> *mut ExprBatch
Create a new expression batch with its own arena

This creates both an arena and a batch in a single allocation. The arena is automatically sized based on the size_hint parameter.

Parameters

  • size_hint: Suggested arena size in bytes (0 for default of 8KB)

Returns

Pointer to new batch, or NULL on failure

Safety

  • The returned pointer must be freed with expr_batch_free()